%define anolis_release 1

%global appstream_version 0.14.0
%global flatpak_version 1.5.1
%global fwupd_version 1.3.3
%global glib2_version 2.61.1
%global gtk4_version 4.9.2
%global json_glib_version 1.2.0
%global libadwaita_version 1.3.alpha
%global libsoup_version 2.52.0
%global libxmlb_version 0.1.7
%global packagekit_version 1.1.1

%{!?with_webapps: %global with_webapps 0}

# this is not a library version
%define gs_plugin_version 20

%global tarball_version %%(echo %{version} | tr '~' '.')

%global __provides_exclude_from ^%{_libdir}/%{name}/plugins-%{gs_plugin_version}/.*\\.so.*$

Name:      gnome-software
Version:   44.0
Release:   %{anolis_release}%{dist}

Summary:   A software center for GNOME

License:   GPL-2.0-or-later
URL:       https://wiki.gnome.org/Apps/Software
Source0:   https://download.gnome.org/sources/gnome-software/44/%{name}-%{tarball_version}.tar.xz

Patch0001: 0001-crash-with-broken-theme.patch

BuildRequires: docbook-style-xsl
BuildRequires: desktop-file-utils
BuildRequires: gcc
BuildRequires: gettext
BuildRequires: gtk-doc
BuildRequires: libxslt
BuildRequires: meson
BuildRequires: pkgconfig(appstream) >= %{appstream_version}
BuildRequires: pkgconfig(flatpak) >= %{flatpak_version}
BuildRequires: pkgconfig(fwupd) >= %{fwupd_version}
BuildRequires: pkgconfig(gdk-pixbuf-2.0)
BuildRequires: pkgconfig(gio-unix-2.0) >= %{glib2_version}
BuildRequires: pkgconfig(glib-2.0) >= %{glib2_version}
BuildRequires: pkgconfig(gmodule-2.0) >= %{glib2_version}
BuildRequires: pkgconfig(gsettings-desktop-schemas)
BuildRequires: pkgconfig(gtk4) >= %{gtk4_version}
BuildRequires: pkgconfig(gudev-1.0)
BuildRequires: pkgconfig(json-glib-1.0) >= %{json_glib_version}
BuildRequires: pkgconfig(libadwaita-1) >= %{libadwaita_version}
BuildRequires: pkgconfig(libdnf)
BuildRequires: pkgconfig(libsoup-2.4)
BuildRequires: pkgconfig(malcontent-0)
BuildRequires: pkgconfig(ostree-1)
BuildRequires: pkgconfig(packagekit-glib2) >= %{packagekit_version}
BuildRequires: pkgconfig(polkit-gobject-1)
BuildRequires: pkgconfig(rpm)
BuildRequires: pkgconfig(rpm-ostree-1)
BuildRequires: pkgconfig(sysprof-capture-4)
BuildRequires: pkgconfig(xmlb) >= %{libxmlb_version}

Requires: appstream-data
Requires: appstream >= %{appstream_version}
%if %{with_webapps}
Requires: epiphany-runtime
%endif
Requires: flatpak >= %{flatpak_version}
Requires: flatpak-libs >= %{flatpak_version}
Requires: fwupd >= %{fwupd_version}
Requires: glib2 >= %{glib2_version}
# gnome-menus is needed for app folder .directory entries
Requires: gnome-menus
Requires: gsettings-desktop-schemas
Requires: json-glib >= %{json_glib_version}
Requires: iso-codes
# librsvg2 is needed for gdk-pixbuf svg loader
Requires: librsvg2
Requires: libsoup >= %{libsoup_version}
Requires: libxmlb >= %{libxmlb_version}

Recommends: PackageKit >= %{packagekit_version}

Obsoletes: gnome-software-snap < 3.33.1
Obsoletes: gnome-software-editor < 3.35.1

%description
gnome-software is an application that makes it easy to add, remove
and update software in the GNOME desktop.

%package devel
Summary: Headers for building external gnome-software plugins
Requires: %{name} = %{version}-%{release}

%description devel
These development files are for building gnome-software plugins outside
the source tree. Most users do not need this subpackage installed.

%package rpm-ostree
Summary: rpm-ostree backend for gnome-software
Requires: %{name} = %{version}-%{release}
Requires: rpm-ostree
Supplements: (gnome-software and rpm-ostree)

%description rpm-ostree
gnome-software is an application that makes it easy to add, remove
and update software in the GNOME desktop.

This package includes the rpm-ostree backend.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1 -S gendiff -n %{name}-%{tarball_version}

%build
%meson \
    -Dsoup2=true \
    -Dsnap=false \
    -Dmalcontent=true \
    -Dgudev=true \
    -Dpackagekit=true \
    -Dpackagekit_autoremove=true \
    -Dexternal_appstream=false \
    -Drpm_ostree=true \
%if %{with_webapps}
    -Dwebapps=true \
    -Dhardcoded_foss_webapps=true \
    -Dhardcoded_proprietary_webapps=false \
%else
    -Dwebapps=false \
    -Dhardcoded_foss_webapps=false \
    -Dhardcoded_proprietary_webapps=false \
%endif
    -Dtests=false
%meson_build

%install
%meson_install

# Remove any piece of doc that ends up in non-standard locations and use the doc macro instead
rm %{buildroot}%{_datadir}/doc/%{name}/README.md
# remove unneeded dpkg plugin
rm %{buildroot}%{_libdir}/gnome-software/plugins-%{gs_plugin_version}/libgs_plugin_dpkg.so

# make the software center load faster
desktop-file-edit %{buildroot}%{_datadir}/applications/org.gnome.Software.desktop \
    --set-key=X-AppInstall-Package --set-value=%{name}


%find_lang %name --with-gnome

%check
desktop-file-validate %{buildroot}%{_datadir}/applications/*.desktop

%generate_compatibility_deps

%files -f %{name}.lang
%license COPYING
%dir %{abidir}
%{_bindir}/gnome-software
%{_datadir}/applications/gnome-software-local-file-flatpak.desktop
%{_datadir}/applications/gnome-software-local-file-fwupd.desktop
%{_datadir}/applications/gnome-software-local-file-packagekit.desktop
%{_datadir}/applications/org.gnome.Software.desktop
%{_mandir}/man1/gnome-software.1*
%{_datadir}/icons/hicolor/*/apps/org.gnome.Software.svg
%{_datadir}/icons/hicolor/symbolic/apps/org.gnome.Software-symbolic.svg
%{_datadir}/icons/hicolor/scalable/actions/app-remove-symbolic.svg
%{_datadir}/metainfo/org.gnome.Software.metainfo.xml
%if %{with_webapps}
%{_datadir}/metainfo/org.gnome.Software.Plugin.Epiphany.metainfo.xml
%endif
%{_datadir}/metainfo/org.gnome.Software.Plugin.Flatpak.metainfo.xml
%{_datadir}/metainfo/org.gnome.Software.Plugin.Fwupd.metainfo.xml
%dir %{_libdir}/gnome-software/plugins-%{gs_plugin_version}
%{_libdir}/gnome-software/libgnomesoftware.so.%{gs_plugin_version}
%{abidir}/libgnomesoftware.dump
%{_libdir}/gnome-software/plugins-%{gs_plugin_version}/libgs_plugin_appstream.so
%{abidir}/libgs_plugin_appstream.dump
%{_libdir}/gnome-software/plugins-%{gs_plugin_version}/libgs_plugin_dummy.so
%{abidir}/libgs_plugin_dummy.dump
%if %{with_webapps}
%{_libdir}/gnome-software/plugins-%{gs_plugin_version}/libgs_plugin_epiphany.so
%{abidir}/libgs_plugin_epiphany.dump
%endif
%{_libdir}/gnome-software/plugins-%{gs_plugin_version}/libgs_plugin_fedora-langpacks.so
%{abidir}/libgs_plugin_fedora-langpacks.dump
%{_libdir}/gnome-software/plugins-%{gs_plugin_version}/libgs_plugin_fedora-pkgdb-collections.so
%{abidir}/libgs_plugin_fedora-pkgdb-collections.dump
%{_libdir}/gnome-software/plugins-%{gs_plugin_version}/libgs_plugin_flatpak.so
%{abidir}/libgs_plugin_flatpak.dump
%{_libdir}/gnome-software/plugins-%{gs_plugin_version}/libgs_plugin_fwupd.so
%{abidir}/libgs_plugin_fwupd.dump
%{_libdir}/gnome-software/plugins-%{gs_plugin_version}/libgs_plugin_generic-updates.so
%{abidir}/libgs_plugin_generic-updates.dump
%{_libdir}/gnome-software/plugins-%{gs_plugin_version}/libgs_plugin_hardcoded-blocklist.so
%{abidir}/libgs_plugin_hardcoded-blocklist.dump
%{_libdir}/gnome-software/plugins-%{gs_plugin_version}/libgs_plugin_icons.so
%{abidir}/libgs_plugin_icons.dump
%{_libdir}/gnome-software/plugins-%{gs_plugin_version}/libgs_plugin_malcontent.so
%{abidir}/libgs_plugin_malcontent.dump
%{_libdir}/gnome-software/plugins-%{gs_plugin_version}/libgs_plugin_modalias.so
%{abidir}/libgs_plugin_modalias.dump
%{_libdir}/gnome-software/plugins-%{gs_plugin_version}/libgs_plugin_os-release.so
%{abidir}/libgs_plugin_os-release.dump
%{_libdir}/gnome-software/plugins-%{gs_plugin_version}/libgs_plugin_packagekit.so
%{abidir}/libgs_plugin_packagekit.dump
%{_libdir}/gnome-software/plugins-%{gs_plugin_version}/libgs_plugin_provenance-license.so
%{abidir}/libgs_plugin_provenance-license.dump
%{_libdir}/gnome-software/plugins-%{gs_plugin_version}/libgs_plugin_provenance.so
%{abidir}/libgs_plugin_provenance.dump
%{_libdir}/gnome-software/plugins-%{gs_plugin_version}/libgs_plugin_repos.so
%{abidir}/libgs_plugin_repos.dump
%{_libdir}/gnome-software/plugins-%{gs_plugin_version}/libgs_plugin_rewrite-resource.so
%{abidir}/libgs_plugin_rewrite-resource.dump
%{_sysconfdir}/xdg/autostart/org.gnome.Software.desktop
%dir %{_datadir}/swcatalog
%dir %{_datadir}/swcatalog/xml
%if %{with_webapps}
%{_datadir}/swcatalog/xml/gnome-pwa-list-foss.xml
%endif
%{_datadir}/swcatalog/xml/org.gnome.Software.Curated.xml
%{_datadir}/swcatalog/xml/org.gnome.Software.Featured.xml
%{_datadir}/dbus-1/services/org.freedesktop.PackageKit.service
%{_datadir}/dbus-1/services/org.gnome.Software.service
%{_datadir}/gnome-shell/search-providers/org.gnome.Software-search-provider.ini
%{_datadir}/glib-2.0/schemas/org.gnome.software.gschema.xml
%{_libexecdir}/gnome-software-cmd
%{_libexecdir}/gnome-software-restarter

%files rpm-ostree
%{_libdir}/gnome-software/plugins-%{gs_plugin_version}/libgs_plugin_rpm-ostree.so
%{abidir}/libgs_plugin_rpm-ostree.dump

%files devel
%{_libdir}/pkgconfig/gnome-software.pc
%dir %{_includedir}/gnome-software
%{_includedir}/gnome-software/*.h
%{_libdir}/gnome-software/libgnomesoftware.so
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html
%{_datadir}/gtk-doc/html/gnome-software/

%files doc
%doc AUTHORS README.md

%changelog
* Sat Mar 18 2023 yuanhui <yuanhui@linux.alibaba.com> - 44.0-1
- Init package from upstream
